# ResearchResourceProposalV30Rc1

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**title** | [**ResearchResourceTitleV30Rc1**](ResearchResourceTitleV30Rc1.md) |  | [optional] 
**hosts** | [**ResearchResourceHostsV30Rc1**](ResearchResourceHostsV30Rc1.md) |  | [optional] 
**external_ids** | [**ExternalIDsV30Rc1**](ExternalIDsV30Rc1.md) |  | [optional] 
**start_date** | [**FuzzyDateV30Rc1**](FuzzyDateV30Rc1.md) |  | [optional] 
**end_date** | [**FuzzyDateV30Rc1**](FuzzyDateV30Rc1.md) |  | [optional] 
**url** | [**UrlV30Rc1**](UrlV30Rc1.md) |  | [optional] 

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)

